// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef CANTOR_VERSION_H
#define CANTOR_VERSION_H

#define CANTOR_VERSION_STRING "23.08.5"
#define CANTOR_VERSION_MAJOR 23
#define CANTOR_VERSION_MINOR 8
#define CANTOR_VERSION_PATCH 5
#define CANTOR_VERSION ((23<<16)|(8<<8)|(5))

#endif
